@@ -2,6 +2,6 @@ from pkg_resources import DistributionNotFound, get_distribution
 
 try:
     __version__ = get_distribution("localtileserver").version
-except DistributionNotFound:
+except DistributionNotFound:  # pragma: no cover
     # package is not installed
     __version__ = None
