@@ -1,13 +1,23 @@
 # flake8: noqa: W503
 from functools import wraps
+import json
 import logging
 import pathlib
 from typing import List, Union
+from urllib.parse import quote
 
+from large_image.tilesource import FileTileSource
 import requests
 
+try:
+    from rasterio.io import DatasetReaderBase
+except ImportError:
+    DatasetReaderBase = None
+
+from server_thread import ServerManager, launch_server
+
 from localtileserver.configure import get_default_client_params
-from localtileserver.server import ServerManager, launch_server
+from localtileserver.manager import AppManager
 from localtileserver.tileserver import get_building_docs, get_clean_filename, palette_valid_or_raise
 from localtileserver.utilities import add_query_parameters, save_file_from_request
 
@@ -38,15 +48,15 @@ class BaseTileClient:
 
     @property
     def server_host(self):
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: no cover
 
     @property
     def server_port(self):
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: no cover
 
     @property
     def server_base_url(self):
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: no cover
 
     def _produce_url(self, base: str):
         return add_query_parameters(base, {"filename": self._filename})
@@ -54,6 +64,42 @@ class BaseTileClient:
     def create_url(self, path: str):
         return self._produce_url(f"{self.server_base_url}/{path.lstrip('/')}")
 
+    def _get_style_params(
+        self,
+        band: Union[int, List[int]] = None,
+        palette: Union[str, List[str]] = None,
+        vmin: Union[Union[float, int], List[Union[float, int]]] = None,
+        vmax: Union[Union[float, int], List[Union[float, int]]] = None,
+        nodata: Union[Union[float, int], List[Union[float, int]]] = None,
+        scheme: Union[str, List[str]] = None,
+        n_colors: int = 255,
+        style: dict = None,
+        cmap: Union[str, List[str]] = None,
+    ):
+        if style:
+            return {"style": quote(json.dumps(style))}
+        # First handle query parameters to check for errors
+        params = {}
+        if band is not None:
+            params["band"] = band
+        if palette is not None or cmap is not None:
+            if palette is None:
+                palette = cmap
+            # make sure palette is valid
+            palette_valid_or_raise(palette)
+            params["palette"] = palette
+        if vmin is not None:
+            params["min"] = vmin
+        if vmax is not None:
+            params["max"] = vmax
+        if nodata is not None:
+            params["nodata"] = nodata
+        if scheme is not None:
+            params["scheme"] = scheme
+        if n_colors:
+            params["n_colors"] = n_colors
+        return params
+
     def get_tile_url_params(
         self,
         projection: str = "EPSG:3857",
@@ -65,6 +111,8 @@ class BaseTileClient:
         scheme: Union[str, List[str]] = None,
         n_colors: int = 255,
         grid: bool = False,
+        style: dict = None,
+        cmap: Union[str, List[str]] = None,
     ):
         """Get slippy maps tile URL (e.g., `/zoom/x/y.png`).
 
@@ -102,30 +150,28 @@ class BaseTileClient:
         grid : bool
             Show the outline of each tile. This is useful when debugging your
             tile viewer.
+        style : dict, optional
+            large-image JSON style. See
+            https://girder.github.io/large_image/tilesource_options.html#style
+            If given, this will override all other styling parameters.
+        cmap : str
+            Alias for palette if not specified.
 
         """
-        # First handle query parameters to check for errors
-        params = {}
-        if band is not None:
-            params["band"] = band
-        if palette is not None:
-            # make sure palette is valid
-            palette_valid_or_raise(palette)
-            params["palette"] = palette
-        if vmin is not None:
-            params["min"] = vmin
-        if vmax is not None:
-            params["max"] = vmax
-        if nodata is not None:
-            params["nodata"] = nodata
-        if projection is not None:
-            params["projection"] = projection
+        params = self._get_style_params(
+            band=band,
+            palette=palette,
+            vmin=vmin,
+            vmax=vmax,
+            nodata=nodata,
+            scheme=scheme,
+            n_colors=n_colors,
+            style=style,
+            cmap=cmap,
+        )
+        params["projection"] = projection
         if grid:
             params["grid"] = True
-        if scheme is not None:
-            params["scheme"] = scheme
-        if n_colors:
-            params["n_colors"] = n_colors
         return params
 
     @wraps(get_tile_url_params)
@@ -194,25 +240,21 @@ class BaseTileClient:
         scheme: Union[str, List[str]] = None,
         n_colors: int = 255,
         output_path: pathlib.Path = None,
+        style: dict = None,
+        cmap: Union[str, List[str]] = None,
     ):
-        params = {}
-        if band is not None:
-            params["band"] = band
-        if palette is not None:
-            # make sure palette is valid
-            palette_valid_or_raise(palette)
-            params["palette"] = palette
-        if vmin is not None:
-            params["min"] = vmin
-        if vmax is not None:
-            params["max"] = vmax
-        if nodata is not None:
-            params["nodata"] = nodata
-        if scheme is not None:
-            params["scheme"] = scheme
-        if n_colors:
-            params["n_colors"] = n_colors
-        url = add_query_parameters(self.create_url("api/thumbnail"), params)
+        params = self._get_style_params(
+            band=band,
+            palette=palette,
+            vmin=vmin,
+            vmax=vmax,
+            nodata=nodata,
+            scheme=scheme,
+            n_colors=n_colors,
+            style=style,
+            cmap=cmap,
+        )
+        url = add_query_parameters(self.create_url("api/thumbnail.png"), params)
         r = requests.get(url)
         r.raise_for_status()
         return save_file_from_request(r, output_path)
@@ -243,18 +285,46 @@ class BaseTileClient:
         r.raise_for_status()
         return r.json()
 
-    def histogram(self, bins: int = 256, density: bool = False, format: str = None):
+    def histogram(self, bins: int = 256, density: bool = False):
         """Get a histoogram for each band."""
         params = {}
         params["density"] = density
         params["bins"] = bins
-        if format is not None:
-            params["format"] = format
         url = add_query_parameters(self.create_url("api/histogram"), params)
         r = requests.get(url)
         r.raise_for_status()
         return r.json()
 
+    @property
+    def default_zoom(self):
+        m = self.metadata()
+        try:
+            return m["levels"] - m["sourceLevels"]
+        except KeyError:
+            return 0
+
+    @property
+    def is_geospatial(self):
+        return self.metadata().get("geospatial", False)
+
+    def _ipython_display_(self):
+        if not self.is_geospatial:
+            raise NotImplementedError
+
+        from IPython.display import display
+        from ipyleaflet import Map
+
+        from localtileserver.widgets import get_leaflet_tile_layer
+
+        t = get_leaflet_tile_layer(self)
+        m = Map(center=self.center(), zoom=self.default_zoom)
+        m.add_layer(t)
+        return display(m)
+
+    def _repr_png_(self):
+        with open(self.thumbnail(), "rb") as f:
+            return f.read()
+
 
 class RemoteTileClient(BaseTileClient):
     """Connect to a remote localtileserver instance at a given host URL.
@@ -299,17 +369,13 @@ class TileClient(BaseTileClient):
 
     Parameters
     ----------
-    path : pathlib.Path, str
+    path : pathlib.Path, str, rasterio.io.DatasetReaderBase
         The path on disk to use as the source raster for the tiles.
     port : int
         The port on your host machine to use for the tile server. This defaults
         to getting an available port.
     debug : bool
         Run the tile server in debug mode.
-    threaded : bool
-        Run the background server as a ThreadedWSGIServer. Default True.
-    processes : int
-        If processes is greater than 1, run background server as ForkingWSGIServer
     client_port : int
         The port on your client browser to use for fetching tiles. This is
         useful when running in Docker and performing port forwarding.
@@ -320,18 +386,26 @@ class TileClient(BaseTileClient):
 
     def __init__(
         self,
-        filename: Union[pathlib.Path, str],
+        filename: Union[pathlib.Path, str, DatasetReaderBase, FileTileSource],
         port: Union[int, str] = "default",
         debug: bool = False,
-        threaded: bool = True,
-        processes: int = 1,
         host: str = "127.0.0.1",
         client_port: int = None,
         client_host: str = None,
         client_prefix: str = None,
+        cors_all: bool = False,
     ):
+        if (
+            DatasetReaderBase
+            and isinstance(filename, DatasetReaderBase)
+            and hasattr(filename, "name")
+        ):
+            filename = filename.name
+        elif isinstance(filename, FileTileSource):
+            filename = filename._getLargeImagePath()
         super().__init__(filename)
-        self._key = launch_server(port, debug, threaded=threaded, processes=processes, host=host)
+        app = AppManager.get_or_create_app(cors_all=cors_all)
+        self._key = launch_server(app, port=port, debug=debug, host=host)
         # Store actual port just in case
         self._port = ServerManager.get_server(self._key).srv.port
         client_host, client_port, client_prefix = get_default_client_params(
@@ -343,6 +417,14 @@ class TileClient(BaseTileClient):
         if BUILDING_DOCS and not client_host:
             self._client_host = DEMO_REMOTE_TILE_SERVER
 
+        if not debug:
+            logging.getLogger("gdal").setLevel(logging.ERROR)
+            logging.getLogger("large_image").setLevel(logging.ERROR)
+        else:
+            logging.getLogger("gdal").setLevel(logging.DEBUG)
+            logging.getLogger("large_image").setLevel(logging.DEBUG)
+            logging.getLogger("large_image_source_gdal").setLevel(logging.DEBUG)
+
     def shutdown(self, force: bool = False):
         if hasattr(self, "_key"):
             ServerManager.shutdown_server(self._key, force=force)
@@ -430,11 +512,9 @@ class TileClient(BaseTileClient):
 
 
 def get_or_create_tile_client(
-    source: Union[pathlib.Path, str, TileClient],
+    source: Union[pathlib.Path, str, TileClient, DatasetReaderBase, FileTileSource],
     port: Union[int, str] = "default",
     debug: bool = False,
-    threaded: bool = True,
-    processes: int = 1,
 ):
     """A helper to safely get a TileClient from a path on disk.
 
@@ -450,7 +530,7 @@ def get_or_create_tile_client(
     _internally_created = False
     # Launch tile server if file path is given
     if not isinstance(source, TileClient):
-        source = TileClient(source, port=port, debug=debug, threaded=threaded, processes=processes)
+        source = TileClient(source, port=port, debug=debug)
         _internally_created = True
     # Check that the tile source is valid and no server errors
     try:
