@@ -21,10 +21,12 @@ class Report(scooby.Report):
             "localtileserver",
             "flask",
             "flask_caching",
+            "flask_cors",
             "flask_restx",
             "requests",
             "werkzeug",
             "click",
+            "server_thread",
             "scooby",
         ] + large_image_core
 
@@ -45,6 +47,7 @@ class Report(scooby.Report):
             "large_image_converter",
             "tifftools",
             "pyvips",
+            "pylibtiff",
         ]
 
         scooby.Report.__init__(
