@@ -28,8 +28,9 @@ def get_pine_gulch_url():
 
 
 def get_sf_bay_url():
-    # https://data.kitware.com/#item/60747d792fa25629b9a79538
-    return "https://data.kitware.com/api/v1/file/60747d792fa25629b9a79565/download"
+    # Non-COG: https://data.kitware.com/#item/60747d792fa25629b9a79538
+    # COG: https://data.kitware.com/#item/626854a04acac99f42126a72
+    return "https://data.kitware.com/api/v1/file/626854a14acac99f42126a74/download"
 
 
 def get_elevation_us_url():
@@ -38,3 +39,12 @@ def get_elevation_us_url():
 
 def get_oam2_url():
     return "https://oin-hotosm.s3.amazonaws.com/59c66c5223c8440011d7b1e4/0/7ad397c0-bba2-4f98-a08a-931ec3a6e943.tif"
+
+
+def convert_dropbox_url(url: str):
+    return url.replace("https://www.dropbox.com", "https://dl.dropbox.com")
+
+
+def clean_url(url: str):
+    """Fix the download URL for common hosting services like dropbox."""
+    return convert_dropbox_url(url)
