@@ -10,7 +10,7 @@ tileserver.add_url_rule("/split/form/", view_func=views.SplitViewForm.as_view("s
 # REST endpoints
 rest.api.add_resource(
     rest.ThumbnailView,
-    "/thumbnail",
+    "/thumbnail.png",
     endpoint="thumbnail",
 )
 rest.api.add_resource(
@@ -63,3 +63,8 @@ rest.api.add_resource(
     "/sources",
     endpoint="sources",
 )
+rest.api.add_resource(
+    rest.ValidateCOGView,
+    "/validate",
+    endpoint="validate",
+)
