@@ -3,6 +3,11 @@ import os
 import pathlib
 from typing import List, Union
 
+try:
+    from rasterio.io import DatasetReaderBase
+except ImportError:
+    DatasetReaderBase = None
+
 from localtileserver.client import TileClient, get_or_create_tile_client
 
 logger = logging.getLogger(__name__)
@@ -10,7 +15,7 @@ DEFAULT_ATTRIBUTION = "Raster file served by <a href='https://github.com/banesul
 
 
 def get_leaflet_tile_layer(
-    source: Union[pathlib.Path, str, TileClient],
+    source: Union[pathlib.Path, str, TileClient, DatasetReaderBase],
     port: Union[int, str] = "default",
     debug: bool = False,
     projection: str = "EPSG:3857",
@@ -22,13 +27,15 @@ def get_leaflet_tile_layer(
     scheme: Union[str, List[str]] = None,
     n_colors: int = 255,
     attribution: str = None,
+    style: dict = None,
+    cmap: Union[str, List[str]] = None,
     **kwargs,
 ):
     """Generate an ipyleaflet TileLayer for the given TileClient.
 
     Parameters
     ----------
-    source : Union[pathlib.Path, str, TileClient]
+    source : Union[pathlib.Path, str, TileClient, rasterio.io.DatasetReaderBase]
         The source of the tile layer. This can be a path on disk or an already
         open ``TileClient``
     port : int
@@ -68,6 +75,12 @@ def get_leaflet_tile_layer(
     attribution : str
         Attribution for the source raster. This
         defaults to a message about it being a local file.
+    style : dict, optional
+        large-image JSON style. See
+        https://girder.github.io/large_image/tilesource_options.html#style
+        If given, this will override all other styling parameters.
+    cmap : str
+        Alias for palette if not specified.
     **kwargs
         All additional keyword arguments are passed to ``ipyleaflet.TileLayer``.
 
@@ -80,7 +93,7 @@ def get_leaflet_tile_layer(
     try:
         from ipyleaflet import TileLayer
         from traitlets import Tuple, Union
-    except ImportError as e:
+    except ImportError as e:  # pragma: no cover
         raise ImportError(f"Please install `ipyleaflet`: {e}")
 
     class BoundTileLayer(TileLayer):
@@ -98,6 +111,8 @@ def get_leaflet_tile_layer(
         nodata=nodata,
         scheme=scheme,
         n_colors=n_colors,
+        style=style,
+        cmap=cmap,
         client=True,
     )
     if attribution is None:
@@ -111,7 +126,7 @@ def get_leaflet_tile_layer(
 
 
 def get_leaflet_roi_controls(
-    tile_client: TileClient,
+    client: TileClient,
     button_position: str = "topright",
     output_directory: pathlib.Path = ".",
     debug: bool = False,
@@ -137,7 +152,7 @@ def get_leaflet_roi_controls(
         from ipyleaflet import DrawControl, WidgetControl
         import ipywidgets as widgets
         from shapely.geometry import Polygon
-    except ImportError as e:
+    except ImportError as e:  # pragma: no cover
         raise ImportError(f"Please install `ipyleaflet` and `shapely`: {e}")
     draw_control = DrawControl()
     # Disable polyline and circle
@@ -178,7 +193,7 @@ def get_leaflet_roi_controls(
                 p = p.union(t)
         left, bottom, right, top = p.bounds
         # Get filename in working directory
-        split = os.path.basename(tile_client.filename).split(".")
+        split = os.path.basename(client.filename).split(".")
         ext = split[-1]
         basename = ".".join(split[:1])
         output_path = pathlib.Path(output_directory).absolute()
@@ -186,7 +201,7 @@ def get_leaflet_roi_controls(
         output_path = output_path / f"roi_{basename}_{left}_{right}_{bottom}_{top}.{ext}"
         draw_control.output_path = output_path
         logger.error(f"output_path: {output_path}")
-        tile_client.extract_roi(left, right, bottom, top, output_path=output_path)
+        client.extract_roi(left, right, bottom, top, output_path=output_path)
 
     button = widgets.Button(description="Extract ROI")
     button.on_click(on_button_clicked)
@@ -197,7 +212,7 @@ def get_leaflet_roi_controls(
 
 
 def get_folium_tile_layer(
-    source: Union[pathlib.Path, str, TileClient],
+    source: Union[pathlib.Path, str, TileClient, DatasetReaderBase],
     port: Union[int, str] = "default",
     debug: bool = False,
     projection: str = "EPSG:3857",
@@ -209,13 +224,15 @@ def get_folium_tile_layer(
     scheme: Union[str, List[str]] = None,
     n_colors: int = 255,
     attr: str = None,
+    style: dict = None,
+    cmap: Union[str, List[str]] = None,
     **kwargs,
 ):
     """Generate a folium TileLayer for the given TileClient.
 
     Parameters
     ----------
-    source : Union[pathlib.Path, str, TileClient]
+    source : Union[pathlib.Path, str, TileClient, rasterio.io.DatasetReaderBase]
         The source of the tile layer. This can be a path on disk or an already
         open ``TileClient``
     port : int
@@ -255,6 +272,12 @@ def get_folium_tile_layer(
     attr : str
         Folium requires the custom tile source have an attribution. This
         defaults to a message about it being a local file.
+    style : dict, optional
+        large-image JSON style. See
+        https://girder.github.io/large_image/tilesource_options.html#style
+        If given, this will override all other styling parameters.
+    cmap : str
+        Alias for palette if not specified.
     **kwargs
         All additional keyword arguments are passed to ``folium.TileLayer``.
 
@@ -266,7 +289,7 @@ def get_folium_tile_layer(
     # Safely import folium
     try:
         from folium import TileLayer
-    except ImportError as e:
+    except ImportError as e:  # pragma: no cover
         raise ImportError(f"Please install `folium`: {e}")
     source, created = get_or_create_tile_client(source, port=port, debug=debug)
     url = source.get_tile_url(
@@ -278,6 +301,8 @@ def get_folium_tile_layer(
         nodata=nodata,
         scheme=scheme,
         n_colors=n_colors,
+        style=style,
+        cmap=cmap,
         client=True,
     )
     if attr is None:
