@@ -1,7 +1,9 @@
 import os
 
+import large_image
 import pytest
 import requests
+from server_thread import ServerDownError, ServerManager
 
 from localtileserver.client import (
     DEMO_REMOTE_TILE_SERVER,
@@ -9,8 +11,7 @@ from localtileserver.client import (
     TileClient,
     get_or_create_tile_client,
 )
-from localtileserver.server import ServerDownError, ServerManager
-from localtileserver.tileserver.utilities import get_tile_source
+from localtileserver.tileserver.utilities import get_clean_filename, get_tile_source
 
 skip_pil_source = True
 try:
@@ -29,11 +30,10 @@ def get_content(url):
     return r.content
 
 
-@pytest.mark.parametrize("processes", [1, 5])
-def test_create_tile_client(bahamas_file, processes):
+def test_create_tile_client(bahamas_file):
     assert ServerManager.server_count() == 0
-    tile_client = TileClient(bahamas_file, processes=processes, debug=True)
-    assert tile_client.filename == bahamas_file
+    tile_client = TileClient(bahamas_file, debug=True)
+    assert tile_client.filename == get_clean_filename(bahamas_file)
     assert tile_client.server_port
     assert tile_client.server_base_url
     assert "bounds" in tile_client.metadata()
@@ -89,8 +89,8 @@ def test_multiple_tile_clients_one_server(bahamas, blue_marble):
     tile_url_a = bahamas.get_tile_url().format(z=8, x=72, y=110)
     tile_url_b = blue_marble.get_tile_url().format(z=8, x=72, y=110)
     assert get_content(tile_url_a) != get_content(tile_url_b)
-    thumb_url_a = bahamas.create_url("api/thumbnail")
-    thumb_url_b = blue_marble.create_url("api/thumbnail")
+    thumb_url_a = bahamas.create_url("api/thumbnail.png")
+    thumb_url_b = blue_marble.create_url("api/thumbnail.png")
     assert get_content(thumb_url_a) != get_content(thumb_url_b)
 
 
@@ -118,10 +118,10 @@ def test_extract_roi_pixel_pil(bahamas):
 
 
 def test_caching_query_params(bahamas):
-    thumb_url_a = bahamas.create_url("api/thumbnail")
-    thumb_url_b = bahamas.create_url("api/thumbnail?band=1")
+    thumb_url_a = bahamas.create_url("api/thumbnail.png")
+    thumb_url_b = bahamas.create_url("api/thumbnail.png?band=1")
     assert get_content(thumb_url_a) != get_content(thumb_url_b)
-    thumb_url_c = bahamas.create_url("api/thumbnail")
+    thumb_url_c = bahamas.create_url("api/thumbnail.png")
     assert get_content(thumb_url_a) == get_content(thumb_url_c)
 
 
@@ -179,7 +179,9 @@ def test_get_or_create_tile_client(bahamas_file, remote_file_url):
 def test_pixel(bahamas):
     pix = bahamas.pixel(0, 0)  # pixel space
     assert "bands" in pix
-    pix = bahamas.pixel(24.56, -77.76, units="EPSG:4326")  # world coordinates
+    pix = bahamas.pixel(
+        24.56, -77.76, units="EPSG:4326", projection="EPSG:3857"
+    )  # world coordinates
     assert "bands" in pix
 
 
@@ -193,5 +195,44 @@ def test_custom_palette(bahamas):
     thumbnail = bahamas.thumbnail(
         band=1,
         palette=palette,
+        scheme="discrete",
     )
     assert thumbnail  # TODO: check colors in produced image
+    thumbnail = bahamas.thumbnail(
+        band=1,
+        cmap=palette,
+        scheme="linear",
+    )
+    assert thumbnail  # TODO: check colors in produced image
+
+
+def test_style_dict(bahamas):
+    style = {
+        "bands": [
+            {"band": 1, "palette": ["#000", "#0f0"]},
+        ]
+    }
+    thumbnail = bahamas.thumbnail(
+        style=style,
+    )
+    assert thumbnail  # TODO: check colors in produced image
+
+
+def test_pixel_space_tiles(bahamas_file):
+    client = TileClient(bahamas_file)
+    tile_url = client.get_tile_url(projection=None).format(z=0, x=0, y=0)
+    assert "projection=none" in tile_url.lower()
+    r = requests.get(tile_url)
+    r.raise_for_status()
+    assert r.content
+
+
+def test_large_image_to_client(bahamas_file):
+    src = large_image.open(bahamas_file)
+    tile_client = TileClient(src)
+    assert tile_client.filename == get_clean_filename(bahamas_file)
+    assert "bounds" in tile_client.metadata()
+
+
+def test_default_zoom(bahamas):
+    assert bahamas.default_zoom == 8
