@@ -1,12 +1,13 @@
 import pytest
 
-from localtileserver import Report
+from localtileserver import Report, TileClient
 from localtileserver.tileserver.palettes import (
     get_palette_by_name,
     get_palettes,
     is_valid_palette_name,
     mpl_to_palette,
 )
+from localtileserver.validate import validate_cog
 
 has_mpl = False
 try:
@@ -36,3 +37,9 @@ def test_report():
 
 def test_get_palettes():
     assert isinstance(get_palettes(), dict)
+
+
+def test_cog_validate(remote_file_url):
+    assert validate_cog(remote_file_url)
+    client = TileClient(remote_file_url)
+    assert validate_cog(client)
